@@ -108,7 +108,7 @@ get_colors(struct xio *xio)
 	{ 0x0000,0x0000,0x7fff },
 	{ 0x7fff,0x0000,0x7fff },
 	{ 0x0000,0x7fff,0x7fff },
-	{ 0x3fff,0x3fff,0x3fff }
+	{ 0x3fff,0x3fff,0x3fff },
     };
 
     for (i = 0; i < 16; ++i)
@@ -180,7 +180,7 @@ xio_open_dpy(char *dpy, int argc, char **argv)
     xio->screen = DefaultScreen(xio->dpy);
     xio->depth = DefaultDepth(xio->dpy, xio->screen);
     xio->width = DisplayWidth(xio->dpy, xio->screen);
-    xio->height = DisplayHeight(xio->dpy, xio->height);
+    xio->height = DisplayHeight(xio->dpy, xio->screen);
     xio->root = DefaultRootWindow(xio->dpy);
     xio->cmap = DefaultColormap(xio->dpy, xio->screen);
     xio->xa_del_win = XInternAtom(xio->dpy, "WM_DELETE_WINDOW", False);
@@ -301,7 +301,7 @@ xio_open_win(struct xio *xio, char *geom)
     XSetWMProtocols(xio->dpy, xw->win, &xio->xa_del_win, 1);
 
     xw->title[0] = 0;
-    xio_title(xw, "Hi");
+    xio_title(xw, "AleVT"); // will be reset pretty soon
     /*
     XStoreName(xio->dpy, xw->win, "AleVT " VERSION);
     XSetIconName(xio->dpy, xw->win, "AleVT");
